
zetup.py
========


.. figure:: https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master
   :alt: 


Zimmermann's `Python <http://python.org>`__ package setup
---------------------------------------------------------

.. code:: python


    >>> import zetup
    >>> print(zetup.__version__)
    0.2.2



https://bitbucket.org/userzimmermann/zetup.py

https://github.com/userzimmermann/zetup.py

